interface LinterConfig {
    /**
     * Os arquivos a serem ignorados instantaneamente na leitura,
     * sejá dévido ao nome ou ao seu tamanho em bytes.
     *
     * @param includesInName filtro utilizado para detectar o nome do arquivo,
     * se o arquivo conter em seu interior essa String ele será ignorado.
     *
     * @param maxSize se o arquivo não for excluído pelo nome, o tamanho máximo dirá
     * se ele deve ou não ser ignorado.
     *
     * Se o valor for [false] nenhum arquivo será ignorado.
     */
    ignoreFiles?: false | {
        includesInName?: string[];
        maxSize?: number;
    };
    /**
     * Caracteres/substrings que serão removidos ou substituídos antes da leitura do lizard-py.
     *
     * @param startWith (Regex String) onde a substring que será removida começa, se for um caractere, não inclua o [endWith].
     *
     * @param endWith (Regex String) onde a substring que será removida termina.
     *
     * @param replace valor que substituirá o caractere ou substring.
     *
     * Aviso: só altere os valores padrões se necessário.
     */
    ignoreChars: {
        startWith?: string;
        endWith?: string;
        replace?: string;
        direct?: string;
    }[];
}
interface LizardObject {
    qtdLines: number;
    qtdMethods: number;
    cyclomaticComplexity: number;
    token: number;
    methods: {
        name: string;
        longName: string;
        cyclomaticComplexity: number;
        startLine: number;
        endLine: number;
        parameters: string[];
        filename: string;
        topNestingLevel: number;
        length: number;
        fanIn: number;
        fanOut: number;
        generalFanOut: number;
    }[];
    source: string;
}
export default function classworkLinter(source: string | string[], filename: string, config?: LinterConfig): Promise<LizardObject>;
export {};
