"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const lizard_py_1 = require("lizard-py");
let defaultConfigLinter = {
    ignoreChars: [
        {
            direct: `/*{1,2}[\s\S]*?*/`,
        },
        {
            startWith: `"`,
            endWith: `"`,
            replace: `""`,
        },
        {
            startWith: `'`,
            endWith: `'`,
            replace: `''`,
        },
        {
            startWith: `//`,
            endWith: `\n`,
        },
        {
            direct: `^\s*\n`,
        },
        {
            startWith: ` \\{`,
            replace: `{`,
        },
    ],
};
function classworkLinter(source, filename, config) {
    return __awaiter(this, void 0, void 0, function* () {
        if (!config) {
            config = Object.assign({}, defaultConfigLinter);
        }
        else {
            config = Object.assign(Object.assign(Object.assign({}, defaultConfigLinter), config), { ignoreChars: config.ignoreChars ? config.ignoreChars : defaultConfigLinter.ignoreChars });
        }
        try {
            if (typeof source !== 'string') {
                try {
                    source = source.join('\n');
                }
                catch (e) {
                    source = source.toString();
                }
            }
            for (let x in config.ignoreChars) {
                let chars = config.ignoreChars[x];
                let stringRegex = chars.startWith ?
                    chars.endWith ? `(${chars.startWith})(.+)(${chars.endWith})` : `(${chars.startWith})` :
                    `${chars.direct}`;
                let regex = new RegExp(stringRegex, 'g');
                source = source.replace(regex, chars.replace ? chars.replace : '');
            }
            let regex = new RegExp('}', 'g');
            source = source.replace(regex, '};');
            //Infelizmente, isso se trata de um erro que ainda nãp resolvi no
            //lizard-py. Eu não entendo muito de python e não tenho muita informação sobre o 
            //autor para entrar em contato
            filename = filename.replace(".js", ".java").replace(".ts", ".java").replace(".tsx", ".java");
            const response = (yield lizard_py_1.analyzeSourceCode(filename, source));
            let cyclomaticComplexity = 0;
            for (let x in response.function_list) {
                let f = response.function_list[x];
                cyclomaticComplexity += f.cyclomatic_complexity;
            }
            let methods = response.function_list.map((item) => {
                let funcName = item.long_name.replace(/\( /gs, '(').replace(/\[ /gs, '[');
                return {
                    name: item.name,
                    longName: funcName,
                    cyclomaticComplexity: item.cyclomatic_complexity,
                    startLine: item.start_line,
                    endLine: item.end_line,
                    parameters: item.parameters,
                    filename: item.filename,
                    topNestingLevel: item.top_nesting_level,
                    length: item.length,
                    fanIn: item.fan_in,
                    fanOut: item.fan_out,
                    generalFanOut: item.general_fan_out,
                };
            });
            return {
                qtdLines: response.nloc,
                qtdMethods: response.function_list.length,
                cyclomaticComplexity,
                token: response.token_count,
                methods,
                source,
            };
        }
        catch (error) {
            return {
                qtdLines: 0,
                qtdMethods: 0,
                cyclomaticComplexity: 0,
                token: 0,
                methods: [],
                source: `[error]: ${error}`,
            };
        }
    });
}
exports.default = classworkLinter;
